@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.21';
+$Footprintless::Overlay::VERSION = '1.22';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -46,6 +46,7 @@ sub _dirs_template {
     my $unpack_dir;
     my $resource = $self->_sub_entity('resource');
     if ($resource) {
+        $unpack_dir = temp_dir();
         $self->_extract_resource( $resource, $unpack_dir );
 
         if ($base_dir) {
@@ -214,7 +215,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.21
+version 1.22
 
 =head1 SYNOPSIS
 
@@ -314,6 +315,24 @@ A more complex example:
         }
     }
 
+You can even store your overlay base/template content in a resource.  When
+initialize or update are called, the resource will be downloaded (if not
+already local) and extracted to a temp folder.  The C<base_dir> and
+C<template_dir> paths will be appended to the extract temp folder:
+
+    overlay => {
+        base_dir => 'base',
+        clean => [
+            '/opt/tomcat/'
+        ],
+        hostname => 'localhost',
+        key => 'T',
+        os => 'linux',
+        resource => 'com.pastdev:app-overlay:zip:package:1.0.0',
+        template_dir => 'template',
+        to_dir => '/opt/foo/tomcat'
+    }
+
 =head1 CONSTRUCTORS
 
 =head2 new($entity, $coordinate)
